(package-api)=

# `almanack` Package API

## Base

```{eval-rst}
.. automodule:: almanack.book
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: almanack.cli
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: almanack.git
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

## Reporting

```{eval-rst}
.. automodule:: almanack.reporting.report
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

## Metrics

### Data

```{eval-rst}
.. automodule:: almanack.metrics.data
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

### Remote

```{eval-rst}
.. automodule:: almanack.metrics.remote
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

#### Entropy

```{eval-rst}
.. automodule:: almanack.metrics.entropy.calculate_entropy
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: almanack.metrics.entropy.processing_repositories
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

#### Garden Lattice

##### Understanding

```{eval-rst}
.. automodule:: almanack.metrics.garden_lattice.understanding
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

##### Connectedness

```{eval-rst}
.. automodule:: almanack.metrics.garden_lattice.connectedness
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

##### Practicality

```{eval-rst}
.. automodule:: almanack.metrics.garden_lattice.practicality
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```
